Re: Troubleshoot clone issue to NFS.
- From
Duy Nguyen <pclouds@gmail.com>
- Date
- May 22, 2015, 10:05 UTC
- Message-ID
- <CACsJy8DMqj8sCowZ5f-QZMgrAMFjGOaWfYjZWHxs+jvBsDpp5w@mail.gmail.com>
- In-Reply-To
- <7FAE15F0A93C0144AD8B5FBD584E1C551975ADA4@C111KXTEMBX51.ERF.thomson.com>
On Fri, May 22, 2015 at 3:35 PM, <steve.norman@thomsonreuters.com> wrote:
Show 18 quoted lines
> Tested this change on a couple of versions, first of all on the revision > where things go wrong for me: > > ... > > ~ $ time git clone https://github.com/git/git test > > real 0m8.263s > user 0m10.550s > sys 0m3.763s > > ~ $ time git clone https://github.com/git/git /sami/test > > real 1m3.286s > user 0m12.149s > sys 0m9.192s > > So the patch isn't reducing the time taken when cloning to NAS.
Strange. Maybe there is something else... Anyway some numbers from me. This is nfs3 hosted by Raspberry Pi, accessed over wireless. I just run index-pack on git.git pack instead of full clone.
- v1.8.4.1 34s - v1.8.4.2 519s (oh.. wireless..) - v1.8.4.2 without has_sha1_file() in index-pack.c 33s - v1.8.4.2 + Jeff's mtime patch 36s
-- Duy